cordex.regions package
======================

Submodules
----------

cordex.regions.mask module
--------------------------

.. automodule:: cordex.regions.mask
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cordex.regions
   :members:
   :undoc-members:
   :show-inheritance:
